!
! Write data to a netcdf file
!
!
! Compile with something like:
!
! g95 -o write_netcdf write_netcdf.f90 -I.../netcdf/include -L.../netcdf/lib -lnetcdf
!
! Execute:
!
! ./write_netcdf
!

program write_netcdf
 use netcdf
 implicit none

 integer :: ncid, status, dimids(2), varid
 integer :: i,j
 real :: temp(6,4)

 ! create some data

 do j=1,4
   do i=1,6
     temp(i,j) = i+j
   end do
 end do

 ! create netcdf file called example.nc
 ! nf90_clobber: overwrite if exists

 status = nf90_create('example.nc',nf90_clobber,ncid)
 call check_error(status)

 ! define the dimension longitude and latitude of size
 ! approxiate size

 status = nf90_def_dim(ncid, 'longitude', 6, dimids(1))
 call check_error(status)

 status = nf90_def_dim(ncid, 'latitude', 4, dimids(2))
 call check_error(status)

 ! create a variable temp of type float of the size 6x4
 ! (dimension longitude and latitude).    

 status = nf90_def_var(ncid, 'temp', nf90_float, dimids, varid)
 call check_error(status)

 ! define a string as attribute of the variable

 status = nf90_put_att(ncid, varid, 'units', 'degree Celsius')
 call check_error(status)

 ! define a vector of floats as attribute of the variable

 status = nf90_put_att(ncid, varid, 'valid_range', (/-10.,40./))
 call check_error(status)

 ! end definitions: leave define mode

 status = nf90_enddef(ncid)
 call check_error(status)

 ! store the variable temp in the netcdf file

 status = nf90_put_var(ncid,varid,temp)
 call check_error(status)

 ! close netcdf file and all changes are written to disk

 status = nf90_close(ncid)
 call check_error(status)


 write(6,*) 'example.nc file created. You might now inspect this file'
 write(6,*) 'with the shell command "ncdump example.nc"'

contains

 subroutine check_error(status)
  integer, intent ( in) :: status

  if(status /= nf90_noerr) then
    write(6,*) 'NetCDF error: ',trim(nf90_strerror(status))
    stop "Stopped"
  end if
 end subroutine check_error

end program write_netcdf
